@@ -8,10 +8,10 @@ class view(object):
        to be an active kernel but also that there is no communication between
        the javascript viewer and ipython.
     '''
-    def __init__(self,width=640,height=960,q="",para="",command="",full=1,v=""):
+    def __init__(self,width=640,height=480,q="",para="",command="",full=1,v=""):
         '''Create a iCn3D view.
-            width -- width of container in pixels
-            height -- twice height of container in pixels
+            width -- width of 3D canvas in pixels
+            height -- height of 3D canvas in pixels
             q -- query, e.g., q='mmdbid=1kq2'
             para -- iCn3D parameters (e.g., para='showanno=1&show2d=1') defined at www.ncbi.nlm.nih.gov/Structure/icn3d/icn3d.html#parameters
             command -- iCn3D commands (e.g., command='color spectrum') defined at www.ncbi.nlm.nih.gov/Structure/icn3d/icn3d.html#commands
@@ -30,10 +30,10 @@ class view(object):
         divid = "icn3dviewerUNIQUEID"
         warnid = "icn3dwarningUNIQUEID"
         self.uniqueid = None
-        self.startjs = '''<div id="%s" style="position: relative; width: %dpx; height: %dpx">
+        self.startjs = '''<div id="%s" style="position: relative; width: %dpx; min-height: %dpx; height: auto">
         <p id="%s" style="background-color:#ffcccc;color:black">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the extension: <br>
         <tt>jupyter labextension install jupyterlab_3dmol</tt></p>
-        </div>\n''' % (divid,width,height,warnid)
+        </div>\n''' % (divid,width,2*height,warnid)
         self.startjs += '<script>\n'
         self.endjs = '</script>'
         
@@ -94,7 +94,7 @@ css1
         para = para.replace("&", ",")
         command = unquote(command)
 
-        self.startjs += 'cfg = {divid: "%s", "%s": "%s", width: "%spx", height: "%spx", mobilemenu: 1, notebook: 1, command: '%s', %s};\n' % (divid, queryArray[0], queryArray[1], width, height/2, command, para)
+        self.startjs += 'cfg = {divid: "%s", "%s": "%s", width: "%spx", height: "%spx", mobilemenu: 1, notebook: 1, command: \'%s\', %s};\n' % (divid, queryArray[0], queryArray[1], width, height, command, para)
 
         self.startjs += 'viewerUNIQUEID = new iCn3DUI(cfg);\n'
         
